[libpri-commits] rmudgett: branch group/ccss r1382 - /team/group/ccss/pri_cc.c

SVN commits to the libpri project libpri-commits at lists.digium.com
Thu Dec 10 09:31:53 CST 2009


Author: rmudgett
Date: Thu Dec 10 09:31:49 2009
New Revision: 1382

URL: http://svnview.digium.com/svn/libpri?view=rev&rev=1382
Log:
Don't include a record for CCBSInterrogate response if the record does not have a reference id.

Modified:
    team/group/ccss/pri_cc.c

Modified: team/group/ccss/pri_cc.c
URL: http://svnview.digium.com/svn/libpri/team/group/ccss/pri_cc.c?view=diff&rev=1382&r1=1381&r2=1382
==============================================================================
--- team/group/ccss/pri_cc.c (original)
+++ team/group/ccss/pri_cc.c Thu Dec 10 09:31:49 2009
@@ -1055,14 +1055,19 @@
 	/* Build the CallDetails list. */
 	idx = 0;
 	for (cc_record = master->cc.pool; cc_record; cc_record = cc_record->next) {
-		if ((!cc_record->is_ccnr) != (invoke->operation == ROSE_ETSI_CCBSInterrogate)) {
-			/* Record is not for the requested CCBS/CCNR mode. */
+		if (cc_record->ccbs_reference_id == CC_PTMP_INVALID_ID
+			|| (!cc_record->is_ccnr) != (invoke->operation == ROSE_ETSI_CCBSInterrogate)) {
+			/*
+			 * Record does not have a reference id yet
+			 * or is not for the requested CCBS/CCNR mode.
+			 */
 			continue;
 		}
 		if (party_a_number.valid) {
 			/* The party A number was given. */
 			party_a_number.presentation = cc_record->party_a.number.presentation;
 			if (q931_party_number_cmp(&party_a_number, &cc_record->party_a.number)) {
+				/* Record party A does not match. */
 				continue;
 			}
 		}




More information about the libpri-commits mailing list